@@ -1,14 +1,13 @@
-import nltk
-
-__version__ = "0.2.4"
+__version__ = "0.3.0"
 WORDNET = "wordnet"
 POINCARE = "poincare"
-nltk.download(WORDNET)
-nltk.download('stopwords')
 
 def load(vectors:str=WORDNET):
     if vectors==WORDNET:
         from ffast.wordnet.tokeniser import Tokeniser
+        from nltk import download
+        download(WORDNET)
+        download('stopwords')
         return Tokeniser()
     if vectors==POINCARE:
         from ffast.poincare.tokeniser import Tokeniser
