@@ -6,24 +6,29 @@ from ffast.wordnet.tokens import Token, Tokens
 from ffast.wordnet.utils import (
     WordNet, PREPROCESSOR, 
     VOCABULARY, VOCABULARY_WORDNET, STOPWORDS,
-    SIZE_STOPWORDS, SIZE_WORDNET
+    SIZE_STOPWORDS, SIZE_WORDNET, SIZE_SENTENCE_VECTOR
 )
     
 class Tokeniser:
-    @staticmethod
-    def __len__() -> int:
-        return SIZE_WORDNET
+    def __init__(self) -> None:
+        self.size = SIZE_SENTENCE_VECTOR
+        self.special_tokens = list()
 
-    @staticmethod
-    def encode(text:str) -> Tokens:
-        return Tokens(Tokeniser._tokenise(text))
+    def __len__(self) -> int:
+        return SIZE_WORDNET + SIZE_STOPWORDS + len(self.special_tokens) + 1
 
-    @staticmethod
-    def decode(ids:List[int]) -> Tokens:
-        return Tokens(list(Tokeniser._convert_ids_to_tokens(ids)))
+    def add_special_token(self, token:str) -> None:
+        if token not in self.special_tokens and token not in VOCABULARY_WORDNET and token not in STOPWORDS:
+            self.special_tokens.append(token)
+            self.special_tokens.sort()
 
-    @staticmethod
-    def _tokenise(text:str) -> List[Token]:
+    def encode(self, text:str) -> Tokens:
+        return Tokens(self._tokenise(text))
+
+    def decode(self, ids:List[int]) -> Tokens:
+        return Tokens(list(self._convert_ids_to_tokens(ids)))
+
+    def _tokenise(self, text:str) -> List[Token]:
         words = text.split()
         number_of_words = len(words)
         tokens = [None]*number_of_words
@@ -41,12 +46,12 @@ class Tokeniser:
                         raw_token=raw_token,
                         normalised_token=normalised_token,
                         synset_name=synset_name,
-                        sense_disambiguation_context=text
+                        sense_disambiguation_context=text,
+                        SPECIAL_TOKENS=self.special_tokens
                     )
         return list(filter(lambda token:isinstance(token,Token),tokens))
 
-    @staticmethod
-    def _convert_ids_to_tokens(ids:List[int]) -> Generator[Token,None,None]:
+    def _convert_ids_to_tokens(self, ids:List[int]) -> Generator[Token,None,None]:
         for id in ids:
             if id < SIZE_WORDNET:
                 synset_name = VOCABULARY[id] 
@@ -54,11 +59,16 @@ class Tokeniser:
             elif id < SIZE_WORDNET + SIZE_STOPWORDS:
                 synset_name= None
                 token = STOPWORDS[id-SIZE_WORDNET]
+            elif id < SIZE_WORDNET + SIZE_STOPWORDS + len(self.special_tokens):
+                synset_name= None
+                id_special_token = id - (SIZE_WORDNET+SIZE_STOPWORDS)
+                token = self.special_tokens[id_special_token] 
             else:
                 synset_name= None
-                token = WordNet.UNKNOWN.value
+                token = WordNet.UNKNOWN.value                    
             yield Token(
                 raw_token=PREPROCESSOR.preprocess(token),
                 normalised_token=token,
-                synset_name=synset_name
+                synset_name=synset_name,
+                SPECIAL_TOKENS=self.special_tokens
             )
\ No newline at end of file
